from setuptools import setup, find_packages

setup(
    name='najini',
    version='0.1',
    description='A collection of python-based tools that connect notion with mongodb.',
    author='Joe Easterly',
    packages=find_packages(),
)

